from . import reconstruction

def compute_feature_rect(data_container_array, feature_ids_array_path = None, feature_rect_array_path = None, observer = None) -> int:
  """
  ComputeFeatureRect

  :param data_container_array | DataContainerArray
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param feature_rect_array_path | DataArrayPath FeatureRectArrayPath
  :param observer | Observer
  """

  filter = reconstruction.ComputeFeatureRect()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_rect_array_path is not None:
    filter.FeatureRectArrayPath = feature_rect_array_path
  filter.execute()
  return filter.ErrorCode

def group_features(data_container_array, contiguous_neighbor_list_array_path = None, non_contiguous_neighbor_list_array_path = None, use_non_contiguous_neighbors = None, patch_grouping = None, observer = None) -> int:
  """
  GroupFeatures

  :param data_container_array | DataContainerArray
  :param contiguous_neighbor_list_array_path | DataArrayPath ContiguousNeighborListArrayPath
  :param non_contiguous_neighbor_list_array_path | DataArrayPath NonContiguousNeighborListArrayPath
  :param use_non_contiguous_neighbors | bool UseNonContiguousNeighbors
  :param patch_grouping | bool PatchGrouping
  :param observer | Observer
  """

  filter = reconstruction.GroupFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if contiguous_neighbor_list_array_path is not None:
    filter.ContiguousNeighborListArrayPath = contiguous_neighbor_list_array_path
  if non_contiguous_neighbor_list_array_path is not None:
    filter.NonContiguousNeighborListArrayPath = non_contiguous_neighbor_list_array_path
  if use_non_contiguous_neighbors is not None:
    filter.UseNonContiguousNeighbors = use_non_contiguous_neighbors
  if patch_grouping is not None:
    filter.PatchGrouping = patch_grouping
  filter.execute()
  return filter.ErrorCode

def merge_colonies(data_container_array, new_cell_feature_attribute_matrix_name = None, feature_ids_array_path = None, cell_phases_array_path = None, feature_phases_array_path = None, avg_quats_array_path = None, crystal_structures_array_path = None, cell_parent_ids_array_name = None, glob_alpha_array_name = None, feature_parent_ids_array_name = None, active_array_name = None, axis_tolerance = None, angle_tolerance = None, identify_glob_alpha = None, observer = None) -> int:
  """
  MergeColonies

  :param data_container_array | DataContainerArray
  :param new_cell_feature_attribute_matrix_name | QString NewCellFeatureAttributeMatrixName
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param avg_quats_array_path | DataArrayPath AvgQuatsArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param cell_parent_ids_array_name | QString CellParentIdsArrayName
  :param glob_alpha_array_name | QString GlobAlphaArrayName
  :param feature_parent_ids_array_name | QString FeatureParentIdsArrayName
  :param active_array_name | QString ActiveArrayName
  :param axis_tolerance | float AxisTolerance
  :param angle_tolerance | float AngleTolerance
  :param identify_glob_alpha | bool IdentifyGlobAlpha
  :param observer | Observer
  """

  filter = reconstruction.MergeColonies()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_cell_feature_attribute_matrix_name is not None:
    filter.NewCellFeatureAttributeMatrixName = new_cell_feature_attribute_matrix_name
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if cell_parent_ids_array_name is not None:
    filter.CellParentIdsArrayName = cell_parent_ids_array_name
  if glob_alpha_array_name is not None:
    filter.GlobAlphaArrayName = glob_alpha_array_name
  if feature_parent_ids_array_name is not None:
    filter.FeatureParentIdsArrayName = feature_parent_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if identify_glob_alpha is not None:
    filter.IdentifyGlobAlpha = identify_glob_alpha
  filter.execute()
  return filter.ErrorCode

def merge_twins(data_container_array, new_cell_feature_attribute_matrix_name = None, axis_tolerance = None, angle_tolerance = None, feature_ids_array_path = None, feature_phases_array_path = None, avg_quats_array_path = None, crystal_structures_array_path = None, cell_parent_ids_array_name = None, feature_parent_ids_array_name = None, active_array_name = None, contiguous_neighbor_list_array_path = None, non_contiguous_neighbor_list_array_path = None, use_non_contiguous_neighbors = None, observer = None) -> int:
  """
  MergeTwins

  :param data_container_array | DataContainerArray
  :param new_cell_feature_attribute_matrix_name | QString NewCellFeatureAttributeMatrixName
  :param axis_tolerance | float AxisTolerance
  :param angle_tolerance | float AngleTolerance
  :param feature_ids_array_path | DataArrayPath FeatureIdsArrayPath
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param avg_quats_array_path | DataArrayPath AvgQuatsArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param cell_parent_ids_array_name | QString CellParentIdsArrayName
  :param feature_parent_ids_array_name | QString FeatureParentIdsArrayName
  :param active_array_name | QString ActiveArrayName
  :param contiguous_neighbor_list_array_path | DataArrayPath ContiguousNeighborListArrayPath
  :param non_contiguous_neighbor_list_array_path | DataArrayPath NonContiguousNeighborListArrayPath
  :param use_non_contiguous_neighbors | bool UseNonContiguousNeighbors
  :param observer | Observer
  """

  filter = reconstruction.MergeTwins()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_cell_feature_attribute_matrix_name is not None:
    filter.NewCellFeatureAttributeMatrixName = new_cell_feature_attribute_matrix_name
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if cell_parent_ids_array_name is not None:
    filter.CellParentIdsArrayName = cell_parent_ids_array_name
  if feature_parent_ids_array_name is not None:
    filter.FeatureParentIdsArrayName = feature_parent_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  if contiguous_neighbor_list_array_path is not None:
    filter.ContiguousNeighborListArrayPath = contiguous_neighbor_list_array_path
  if non_contiguous_neighbor_list_array_path is not None:
    filter.NonContiguousNeighborListArrayPath = non_contiguous_neighbor_list_array_path
  if use_non_contiguous_neighbors is not None:
    filter.UseNonContiguousNeighbors = use_non_contiguous_neighbors
  filter.execute()
  return filter.ErrorCode

def segment_features(data_container_array, data_container_name = None, observer = None) -> int:
  """
  SegmentFeatures

  :param data_container_array | DataContainerArray
  :param data_container_name | QString DataContainerName
  :param observer | Observer
  """

  filter = reconstruction.SegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  filter.execute()
  return filter.ErrorCode

def c_axis_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, misorientation_tolerance = None, use_good_voxels = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, good_voxels_array_path = None, feature_ids_array_name = None, active_array_name = None, observer = None) -> int:
  """
  CAxisSegmentFeatures

  :param data_container_array | DataContainerArray
  :param cell_feature_attribute_matrix_name | QString CellFeatureAttributeMatrixName
  :param misorientation_tolerance | float MisorientationTolerance
  :param use_good_voxels | bool UseGoodVoxels
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param quats_array_path | DataArrayPath QuatsArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param active_array_name | QString ActiveArrayName
  :param observer | Observer
  """

  filter = reconstruction.CAxisSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  filter.execute()
  return filter.ErrorCode

def ebsd_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, misorientation_tolerance = None, use_good_voxels = None, good_voxels_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, feature_ids_array_name = None, active_array_name = None, observer = None) -> int:
  """
  EBSDSegmentFeatures

  :param data_container_array | DataContainerArray
  :param cell_feature_attribute_matrix_name | QString CellFeatureAttributeMatrixName
  :param misorientation_tolerance | float MisorientationTolerance
  :param use_good_voxels | bool UseGoodVoxels
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param quats_array_path | DataArrayPath QuatsArrayPath
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param active_array_name | QString ActiveArrayName
  :param observer | Observer
  """

  filter = reconstruction.EBSDSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  filter.execute()
  return filter.ErrorCode

def scalar_segment_features(data_container_array, cell_feature_attribute_matrix_name = None, scalar_array_path = None, scalar_tolerance = None, use_good_voxels = None, good_voxels_array_path = None, feature_ids_array_name = None, active_array_name = None, observer = None) -> int:
  """
  ScalarSegmentFeatures

  :param data_container_array | DataContainerArray
  :param cell_feature_attribute_matrix_name | QString CellFeatureAttributeMatrixName
  :param scalar_array_path | DataArrayPath ScalarArrayPath
  :param scalar_tolerance | float ScalarTolerance
  :param use_good_voxels | bool UseGoodVoxels
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param feature_ids_array_name | QString FeatureIdsArrayName
  :param active_array_name | QString ActiveArrayName
  :param observer | Observer
  """

  filter = reconstruction.ScalarSegmentFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_feature_attribute_matrix_name is not None:
    filter.CellFeatureAttributeMatrixName = cell_feature_attribute_matrix_name
  if scalar_array_path is not None:
    filter.ScalarArrayPath = scalar_array_path
  if scalar_tolerance is not None:
    filter.ScalarTolerance = scalar_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if active_array_name is not None:
    filter.ActiveArrayName = active_array_name
  filter.execute()
  return filter.ErrorCode

def align_sections(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, write_alignment_shifts = None, alignment_shift_file_name = None, observer = None) -> int:
  """
  AlignSections

  :param data_container_array | DataContainerArray
  :param data_container_name | DataArrayPath DataContainerName
  :param cell_attribute_matrix_name | QString CellAttributeMatrixName
  :param write_alignment_shifts | bool WriteAlignmentShifts
  :param alignment_shift_file_name | QString AlignmentShiftFileName
  :param observer | Observer
  """

  filter = reconstruction.AlignSections()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if write_alignment_shifts is not None:
    filter.WriteAlignmentShifts = write_alignment_shifts
  if alignment_shift_file_name is not None:
    filter.AlignmentShiftFileName = alignment_shift_file_name
  filter.execute()
  return filter.ErrorCode

def align_sections_feature(data_container_array, good_voxels_array_path = None, observer = None) -> int:
  """
  AlignSectionsFeature

  :param data_container_array | DataContainerArray
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param observer | Observer
  """

  filter = reconstruction.AlignSectionsFeature()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_feature_centroid(data_container_array, reference_slice = None, use_reference_slice = None, good_voxels_array_path = None, observer = None) -> int:
  """
  AlignSectionsFeatureCentroid

  :param data_container_array | DataContainerArray
  :param reference_slice | int ReferenceSlice
  :param use_reference_slice | bool UseReferenceSlice
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param observer | Observer
  """

  filter = reconstruction.AlignSectionsFeatureCentroid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_slice is not None:
    filter.ReferenceSlice = reference_slice
  if use_reference_slice is not None:
    filter.UseReferenceSlice = use_reference_slice
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_list(data_container_array, input_file = None, dream3_d_alignment_file = None, observer = None) -> int:
  """
  AlignSectionsList

  :param data_container_array | DataContainerArray
  :param input_file | QString InputFile
  :param dream3_d_alignment_file | bool DREAM3DAlignmentFile
  :param observer | Observer
  """

  filter = reconstruction.AlignSectionsList()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if dream3_d_alignment_file is not None:
    filter.DREAM3DAlignmentFile = dream3_d_alignment_file
  filter.execute()
  return filter.ErrorCode

def align_sections_misorientation(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """
  AlignSectionsMisorientation

  :param data_container_array | DataContainerArray
  :param misorientation_tolerance | float MisorientationTolerance
  :param use_good_voxels | bool UseGoodVoxels
  :param quats_array_path | DataArrayPath QuatsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param observer | Observer
  """

  filter = reconstruction.AlignSectionsMisorientation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def align_sections_mutual_information(data_container_array, misorientation_tolerance = None, use_good_voxels = None, quats_array_path = None, cell_phases_array_path = None, good_voxels_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """
  AlignSectionsMutualInformation

  :param data_container_array | DataContainerArray
  :param misorientation_tolerance | float MisorientationTolerance
  :param use_good_voxels | bool UseGoodVoxels
  :param quats_array_path | DataArrayPath QuatsArrayPath
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param observer | Observer
  """

  filter = reconstruction.AlignSectionsMutualInformation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

